@@ -519,8 +519,7 @@ void MineFieldItem::mouseMoveEvent( QGraphicsSceneMouseEvent *ev )
     if( row < 0 || row >= m_numRows || col < 0 || col >= m_numCols )
         return;
 
-    bool midButtonPressed = ((ev->buttons() & Qt::MiddleButton) ||
-                            ( (ev->buttons() & Qt::LeftButton) && (ev->buttons() & Qt::RightButton) ) );
+    const bool midButtonPressed = (ev->buttons() & Qt::MiddleButton) || m_emulatingMidButton;
 
     if(midButtonPressed)
     {
@@ -678,7 +677,7 @@ bool MineFieldItem::sceneEvent( QEvent *ev )
 void MineFieldItem::revealAllMines()
 {
     for (CellItem* item : std::as_const(m_cells)) {
-        if( (item->isFlagged() && !item->hasMine()) || (!item->isFlagged() && item->hasMine()) )
+        if (item->isFlagged() != item->hasMine())
         {
             item->reveal();
             m_numUnrevealed--;
