@@ -11,9 +11,8 @@
 #include "settings.h"
 #include "minefielditem.h"
 // KDEGames
-#include <kdegames_version.h>
 #include <KGamePopupItem>
-#include <KgThemeProvider>
+#include <KGameThemeProvider>
 // KF
 #include <KLocalizedString>
 // Qt
@@ -33,14 +32,10 @@ void KMinesView::resizeEvent( QResizeEvent *ev )
 
 // -------------- KMinesScene --------------------
 
-static KgThemeProvider* provider()
+static KGameThemeProvider* provider()
 {
-    auto* prov = new KgThemeProvider;
-#if KDEGAMES_VERSION >= QT_VERSION_CHECK(7, 4, 0)
+    auto* prov = new KGameThemeProvider;
     prov->discoverThemes(QStringLiteral("themes"));
-#else
-    prov->discoverThemes("appdata", QStringLiteral("themes"));
-#endif
 
     return prov;
 }
